==> telephone-sqlserver-3.0.6.jar: telephone/sqls/getWorklist/manage_telman.sql <==
SELECT
    nam,
    --SUM (denglushichang) AS denglushichang,
    --SUM (zhimangshichang) AS zhimangshichang,
    SUM (zhimangcishu) AS zhimangcishu,
    SUM (weijie)+SUM (yijie) zongji,
    SUM (weijie) AS weijie,
    SUM (yijie) AS yijie,
    SUM (weibo) AS waibo,
    --SUM (jietingshichang) AS jietingshichang,
    --SUM (threesjieting) AS threesjieting,
    SUM (quanbujieting) AS quanbujieting,
    SUM (jieru) AS jieru,
    SUM (jiechu) AS jiechu,
    SUM (zixundan) AS zixundan,
    SUM (tousudan) AS tousudan,
    SUM (baoxiudan) AS baoxiudan,
    SUM (zixundan)+SUM (tousudan)+SUM (baoxiudan)-SUM (yijie) as shoudongluru
FROM
    (
        SELECT
            NAME AS nam,
            SUM (opspan) AS denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan
        FROM
            T_ATTENDANT_STATUS
        WHERE
                operation = '登入'
          AND opstart >= '{startDate}'
          AND opstart <= '{endDate}'
        GROUP BY
            NAME
        UNION ALL
        SELECT
            NAME AS nam,
            0 denglushichang,
            SUM (opspan) AS zhimangshichang,
            COUNT (*) AS zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan
        FROM
            T_ATTENDANT_STATUS
        WHERE
                operation = '置忙'
          AND opstart >= '{startDate}'
          AND opstart <= '{endDate}'
        GROUP BY
            NAME
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            COUNT (*) AS weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan
        FROM
            t_records
        WHERE
                len(starttime) = 0
          and     teltype='呼入'
          AND INLTIME >= '{startDate}'
          AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            COUNT (*) AS yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan
        FROM
            t_records
        WHERE
            len(starttime) != 0
      and     teltype='呼入'
      AND INLTIME >= '{startDate}'
      AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            gonghao AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            COUNT (*) AS weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan
        FROM
            T_CALL_LOG
        WHERE
            islink = 'BZ_CALLOUT'
          AND comingtime >= '{startDate}'
          AND comingtime <= '{endDate}'
        GROUP BY
            gonghao
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            SUM (
            datediff(minute , starttime, endtime)
            ) AS jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan
        FROM
            t_records
        WHERE
            len(starttime) != 0
          and     teltype='呼入'
          AND len(endtime) != 0
          AND INLTIME >= '{startDate}'
          AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            COUNT (*) AS threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan
        FROM
            t_records
        WHERE
            len(starttime) != 0
          AND len(endtime) != 0
          and     teltype='呼入'
          AND datediff(minute , starttime, endtime) < 15
          AND INLTIME >= '{startDate}'
          AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            COUNT (*) AS quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan
        FROM
            t_records
        WHERE
            len(starttime) != 0
          AND len(endtime) != 0
          and     teltype='呼入'
          AND INLTIME >= '{startDate}'
          AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            COUNT (*) AS jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan
        FROM
            t_records
        WHERE
            len(associatedid) != 0
          and     teltype='呼入'
          AND INLTIME >= '{startDate}'
          AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            b.nam AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            COUNT (*) AS jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan
        FROM
            (
            SELECT
            telname AS nam,
            associatedid
            FROM
            t_records
            WHERE
            len(associatedid) != 0
            and     teltype='呼入'
            AND INLTIME >= '{startDate}'
            AND INLTIME <= '{endDate}'
            ) b,
            (
            SELECT
            telname AS nam,
            ID
            FROM
            t_records
            WHERE
            len(associatedid) != 0
            and     teltype='呼入'
            AND INLTIME >= '{startDate}'
            AND INLTIME <= '{endDate}'
            ) c
        WHERE
            b.associatedid = c.ID
        GROUP BY
            b.nam
        UNION ALL
        SELECT
            f_operator_name AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            COUNT (*) zixundan,
            0 tousudan,
            0 baoxiudan
        FROM
            t_consult
        WHERE
            f_created_date >= '{startDate}'
          AND f_created_date <= '{endDate}'
        GROUP BY
            f_operator_name
        UNION ALL
        SELECT
            f_operator_name AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            COUNT (*) tousudan,
            0 baoxiudan
        FROM
            t_complaint
        WHERE
            f_created_date >= '{startDate}'
          AND f_created_date <= '{endDate}'
        GROUP BY
            f_operator_name
        UNION ALL
        SELECT
            f_attendant AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            COUNT (*) baoxiudan
        FROM
            t_service
        WHERE
            f_created_date >= '{startDate}'
          AND f_created_date <= '{endDate}'
        GROUP BY
            f_attendant
    ) ttt
WHERE
        1=1 and nam is not null
GROUP BY
    nam
ORDER BY
    nam

==> telephone-sqlserver-3.0.9.jar: telephone/sqls/getWorklist/manage_telman.sql <==
SELECT
    nam,
    SUM (zhimangcishu) AS zhimangcishu,
    SUM (weijie)+SUM (yijie) zongji,
    SUM (weijie) AS weijie,
    SUM (yijie) AS yijie,
    SUM (weibo) AS waibo,
    SUM (quanbujieting) AS quanbujieting,
    SUM (jieru) AS jieru,
    SUM (jiechu) AS jiechu,
    SUM (zixundan) AS zixundan,
    SUM (tousudan) AS tousudan,
    SUM (baoxiudan) AS baoxiudan,
    SUM(qiangxiu) AS qiangxius,
    SUM(fuwu) AS fuwus,
    SUM(zhenggai) AS zhenggais,
    SUM(zhihuantongqi) AS zhihuantongqis,
    SUM (zixundan)+SUM (tousudan)+SUM (baoxiudan)-SUM (jieru) as shoudongluru
FROM
    (
        SELECT
            NAME AS nam,
            SUM (opspan) AS denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi
        FROM
            T_ATTENDANT_STATUS
        WHERE
                operation = '登入'
          AND opstart >= '{startDate}'
          AND opstart <= '{endDate}'
        GROUP BY
            NAME
        UNION ALL
        SELECT
            NAME AS nam,
            0 denglushichang,
            SUM (opspan) AS zhimangshichang,
            COUNT (*) AS zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi

        FROM
            T_ATTENDANT_STATUS
        WHERE
                operation = '置忙'
          AND opstart >= '{startDate}'
          AND opstart <= '{endDate}'
        GROUP BY
            NAME
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            COUNT (*) AS weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi
        FROM
            t_records
        WHERE
                len(starttime) = 0
          and     teltype='呼入'
          AND INLTIME >= '{startDate}'
          AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            COUNT (*) AS yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi
        FROM
            t_records
        WHERE
            len(starttime) != 0
      and     teltype='呼入'
       AND INLTIME >= '{startDate}'
          AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            gonghao AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            COUNT (*) AS weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi
        FROM
            T_CALL_LOG
        WHERE
            islink = 'BZ_CALLOUT'
          AND comingtime >= '{startDate}'
          AND comingtime <= '{endDate}'
        GROUP BY
            gonghao
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            SUM (
            datediff(minute , starttime, endtime)
            ) AS jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi
        FROM
            t_records
        WHERE
            len(starttime) != 0
          and     teltype='呼入'
          AND len(endtime) != 0
          AND INLTIME >= '{startDate}'
          AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            COUNT (*) AS threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi
        FROM
            t_records
        WHERE
            len(starttime) != 0
          AND len(endtime) != 0
          and     teltype='呼入'
          AND datediff(minute , starttime, endtime) < 15
          AND INLTIME >= '{startDate}'
          AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            COUNT (*) AS quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi
        FROM
            t_records
        WHERE
            len(starttime) != 0
          AND len(endtime) != 0
          and     teltype='呼入'
          AND INLTIME >= '{startDate}'
          AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            telname AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            COUNT (*) AS jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi
        FROM
            t_records
        WHERE
            len(associatedid) != 0
          and     teltype='呼入'
          AND INLTIME >= '{startDate}'
          AND INLTIME <= '{endDate}'
        GROUP BY
            telname
        UNION ALL
        SELECT
            b.nam AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            COUNT (*) AS jiechu,
            0 zixundan,
            0 tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi
        FROM
            (
            SELECT
            telname AS nam,
            associatedid
            FROM
            t_records
            WHERE
            len(associatedid) != 0
            and     teltype='呼入'
            AND INLTIME >= '{startDate}'
            AND INLTIME <= '{endDate}'
            ) b,
            (
            SELECT
            telname AS nam,
            ID
            FROM
            t_records
            WHERE
            len(associatedid) != 0
            and     teltype='呼入'
            AND INLTIME >= '{startDate}'
            AND INLTIME <= '{endDate}'
            ) c
        WHERE
            b.associatedid = c.ID
        GROUP BY
            b.nam
        UNION ALL
        SELECT
            f_operator_name AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            COUNT (*) zixundan,
            0 tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi
        FROM
            t_consult
        WHERE
            f_created_date >= '{startDate}'
          AND f_created_date <= '{endDate}'
        GROUP BY
            f_operator_name
        UNION ALL
        SELECT
            f_operator_name AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            COUNT (*) tousudan,
            0 baoxiudan,
            0 qiangxiu,
            0 fuwu,
            0 zhenggai,
            0 zhihuantongqi
        FROM
            t_complaint
        WHERE
            f_created_date >= '{startDate}'
          AND f_created_date <= '{endDate}'
        GROUP BY
            f_operator_name
        UNION ALL
        SELECT
            f_attendant AS nam,
            0 denglushichang,
            0 zhimangshichang,
            0 zhimangcishu,
            0 weijie,
            0 yijie,
            0 weibo,
            0 jietingshichang,
            0 threesjieting,
            0 quanbujieting,
            0 jieru,
            0 jiechu,
            0 zixundan,
            0 tousudan,
            COUNT (*) baoxiudan,
            sum(case when  f_repairtype='抢修' then 1 else 0 end ) qiangxiu,
            sum(case when  f_repairtype='服务' then 1 else 0 end ) fuwu,
            sum(case when  f_repairtype='整改' then 1 else 0 end ) zhenggai,
            sum(case when  f_repairtype='置换通气' then 1 else 0 end ) zhihuantongqi
        FROM
            t_service
        WHERE
            f_created_date >= '{startDate}'
          AND f_created_date <= '{endDate}'
        GROUP BY
            f_attendant
    ) ttt
WHERE
    {condition} and  1=1 and nam is not null
GROUP BY
    nam
ORDER BY
    nam
